@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Optional, Literal, Union, TypedDict, Any
+from typing import Optional, Literal, Union, TypedDict, Any, overload
 from .operations import FiltrationOperator
 from pydantic import BaseModel, validator
 from sqlalchemy.orm import Query
@@ -140,20 +140,32 @@ class FiltrationData(BaseModel):
     class Config:
         arbitrary_types_allowed = True
 
-    class Default:
-        ...
-
-    class _Default:
-        page_size: int = 10
-        order_by: Optional[str] = None
-        sort_by: Literal["asc", "desc"] = "asc"
+    _default = {"page_size": 10, "order_by": None, "sort_by": "asc"}
 
     @classmethod
     def __get_default(cls, field: str) -> Any:
-        try:
-            return getattr(cls.Default, field)
-        except AttributeError:
-            return getattr(cls._Default, field)
+        return cls._default[field]
+
+    @classmethod
+    @overload
+    def set_default(cls, attr: Literal["page_size"], value: int) -> None:
+        ...
+
+    @classmethod
+    @overload
+    def set_default(cls, attr: Literal["order_by"], value: Optional[str]) -> None:
+        ...
+
+    @classmethod
+    @overload
+    def set_default(
+        cls, attr: Literal["sort_by"], value: Literal["asc", "desc"]
+    ) -> None:
+        ...
+
+    @classmethod
+    def set_default(cls, attr, value):
+        cls._default[attr] = value
 
     @classmethod
     @validator("page_size", pre=True)
@@ -213,4 +225,4 @@ class FiltrationData(BaseModel):
         }
 
         self.to_filter += spec
-        return self
+        return self
\ No newline at end of file
